define pe_repo::repo (
  $installer_build = $title,
  $pe_version      = $::pe_build,
){
  include pe_repo

  $tarball_dir = "puppet-enterprise-${pe_version}-${installer_build}-agent"
  $tarball = "${tarball_dir}.tar.gz"

  pe_staging::deploy { $tarball:
    source  => "${pe_repo::base_path}/${pe_version}/${tarball}",
    target  => $pe_repo::public_dir,
    creates => "${pe_repo::public_dir}/${tarball_dir}",
    require => File[$pe_repo::public_dir],
    mode    => '0755',
  }

  if ! defined(File["${pe_repo::public_dir}/${pe_version}"]) {
    file { "${pe_repo::public_dir}/${pe_version}":
      ensure => directory,
      mode   => '755',
      owner  => root,
      group  => root,
    }

    # These variables are needed by the templates
    $prefix = $pe_repo::prefix
    $master = $pe_repo::master
    $port = $settings::masterport

    file { "${pe_repo::public_dir}/${pe_version}/install.bash":
      ensure  => file,
      mode    => '0644',
      owner   => root,
      group   => root,
      content => template('pe_repo/install.erb'),
    }

    file { "${pe_repo::public_dir}/${pe_version}/upgrade.bash":
      ensure  => file,
      mode    => '0644',
      owner   => root,
      group   => root,
      content => template('pe_repo/upgrade.erb'),
    }
  }

  #our nice symlink to make the .repo files happy
  file { "${pe_repo::public_dir}/${pe_version}/${installer_build}":
    ensure  => link,
    target  => "${pe_repo::public_dir}/${tarball_dir}/agent_packages/${installer_build}",
    require => Pe_staging::Extract[$tarball],
  }
}
